@@ -15,10 +15,10 @@ main (int argc, char **argv)
 
     Glib::RefPtr<SourceLanguageManager> language_manager =
                                                 SourceLanguageManager::create();
-    vector<Glib::ustring > langs = language_manager->get_language_ids ();
+    vector<string> langs = language_manager->get_language_ids ();
     cout << "number of languages found: " << langs.size () << std::endl;;
 
-    for (vector<Glib::ustring>::const_iterator iter = langs.begin(); iter != langs.end (); ++iter) {
+    for (vector<string>::const_iterator iter = langs.begin(); iter != langs.end (); ++iter) {
         if (!(iter->empty())) {
             Glib::RefPtr<SourceLanguage> lang = language_manager->get_language (*iter);
             cout << "language: " << lang->get_name () << std::endl;
